// Copyright 2005 and onwards, Google
// Author: Joe Hughes

function GUH(win) {
  this.win_ = win;
  this.doc_ = this.win_.document;
  listen(this.win_, "load", this._installWatcher.bind(this));
  listen(this.win_, "DOMTitleChanged", this._onTitleChange.bind(this));
}

GUH.prototype._installWatcher = function() {
  this.watcher_ =
    new G_TabbedBrowserWatcher(this.doc_.getElementById("content"), false);
  this.watcher_.registerListener("tabswitch", this._onTabSwitch.bind(this));
  var oldOpenLocation = this.win_.openLocation;
  var urlHider = this;
  this.win_.openLocation = function() {
    urlHider.hideChromeTitle();
    oldOpenLocation();
  }
}

GUH.prototype._onTabSwitch = function(event) {
  if (!event || !event.toBrowser || !event.toBrowser.contentDocument || !event.toBrowser.contentDocument.location) return;
  var uri = event.toBrowser.contentDocument.location.href;
  var title = event.toBrowser.contentDocument.title;
  this.updateLocationBar(uri, title, event.toBrowser.contentDocument);
}

GUH.prototype._onTitleChange = function(event) {
  if (!event || !event.target || !event.target.documentURI || !event.target.title) return;
  var uri = event.target.documentURI;
  var title = event.target.title;
  this.updateLocationBar(uri, title, event.target);
}

GUH.prototype.hideChromeTitle = function() {
  var urlBar = this.doc_.getElementById('urlbar');
  var chromeTitle = this.doc_.getElementById('chrome-title-box');
  urlBar.removeAttribute('hidden');
  chromeTitle.setAttribute('hidden', 'true');
}

GUH.prototype.hideChromeTitleAndSelectURI = function() {
  this.hideChromeTitle();
  var urlBar = this.doc_.getElementById('urlbar');
  urlBar.select();
}

GUH.prototype.showChromeTitle = function() {
  var urlBar = this.doc_.getElementById('urlbar');
  var chromeTitle = this.doc_.getElementById('chrome-title-box');
  chromeTitle.removeAttribute('hidden');
  urlBar.setAttribute('hidden', 'true');
}

GUH.prototype.updateLocationBar = function(uri, title, content) {
  /* If we don't special-case the browser, we'll get updates when
     the window title bar changes. */
  if (uri == 'chrome://browser/content/browser.xul') return;

  if ((uri.indexOf("chrome://") == 0) && (title)) {
    this.doc_.getElementById("chrome-title").value = title;
    this.doc_.getElementById("chrome-title-image").src = content.documentElement.iconURI;
    this.showChromeTitle();
  } else {
    this.hideChromeTitle();
  }
}
